@@ -17,7 +17,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-const MediaInfoNameSpace::Char* MEDIAINFO_TITLE=__T("MediaInfo - http://MediaArea.net/MediaInfo");
+const MediaInfoNameSpace::Char* MEDIAINFO_TITLE=__T("MediaArea.net/MediaInfo");
 ZenLib::Ztring Text_Temp;
 using namespace ZenLib;
 //---------------------------------------------------------------------------
@@ -164,9 +164,11 @@ size_t Core::Menu_File_Open_Files_Continue (const String &FileName)
     //MI->Option(__T("LegacyStreamDisplay"), __T("0"));
     //MI->Option(__T("File_MpegTs_Atsc_transport_stream_id_Trust"), __T("0"));
     //MI->Option(__T("Trace_Level"), __T("Container1;1"));
-    //MI->Option(__T("Language"), __T("raw"));
+    //MI->Option(__T("File_Mxf_TimeCodeFromMaterialPackage"), __T("1"));
     //MI->Option(__T("demux"), __T("container"));
     //MI->Option(__T("file_demux_unpacketize"), __T("1"));
+    //MI->Option(__T("Language"), __T("raw"));
+    //MI->Option(__T("Inform"), __T("PBCore2"));
     return MI->Open(FileName);
 }
 
@@ -221,6 +223,13 @@ void Core::Menu_View_PBCore ()
     Kind=Kind_PBCore;
 }
 
+//---------------------------------------------------------------------------
+void Core::Menu_View_PBCore2 ()
+{
+    MI->Option(__T("Inform"), __T("PBCore2"));
+    Kind=Kind_PBCore2;
+}
+
 //---------------------------------------------------------------------------
 void Core::Menu_View_reVTMD ()
 {
@@ -242,6 +251,27 @@ void Core::Menu_View_EBUCore_1_4 ()
     Kind=Kind_EBUCore_1_4;
 }
 
+//---------------------------------------------------------------------------
+void Core::Menu_View_FIMS_1_1 ()
+{
+    MI->Option(__T("Inform"), __T("FIMS_1.1"));
+    Kind=Kind_FIMS_1_1;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_FIMS_1_2 ()
+{
+    MI->Option(__T("Inform"), __T("FIMS_1.2"));
+    Kind=Kind_FIMS_1_2;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_FIMS_1_3 ()
+{
+    MI->Option(__T("Inform"), __T("FIMS_1.3"));
+    Kind=Kind_FIMS_1_3;
+}
+
 //---------------------------------------------------------------------------
 void Core::Menu_View_Text ()
 {
