@@ -1,21 +1,8 @@
-// GUI of MediaInfo
-// Copyright (C) 2011-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 #define NO_WIN32_LEAN_AND_MEAN
@@ -43,10 +30,9 @@ bool CALLBACK acmDriverEnumCallback (HACMDRIVERID hadid, DWORD dwInstance, DWORD
 {
     Audio_Temp->Separator_Set(0, __T("\r\n"));
     Audio_Temp->Separator_Set(1, __T("aaa"));
-    HACMDRIVER    had;
+    HACMDRIVER had;
     ACMDRIVERDETAILS    add;
-    ACMFORMATTAGDETAILS    aftd;
-    int        v;
+    ACMFORMATTAGDETAILS aftd;
 
     memset (&add, 0, sizeof (ACMDRIVERDETAILS));
     add.cbStruct = sizeof (ACMDRIVERDETAILS);
@@ -86,8 +72,8 @@ void Codecs_Enumerate(ZenLib::ZtringListList &Video, ZenLib::ZtringListList &Aud
     Audio_Temp=&Audio;
 
     //Enumerate VFW Video codecs
-    ICINFO    icinfo;
-    int        count=0;
+    ICINFO  icinfo;
+    int     count=0;
 
      while (ICInfo (ICTYPE_VIDEO, count, &icinfo))
     {
@@ -129,7 +115,7 @@ void Debug_Header_Create(const ZenLib::Ztring &FileName, void* Handle)
     FB2.Write(Tout, Capture);
 
     //Purge
-    delete Tout;
+    delete [] Tout;
     Application->MessageBox(Prefs->Translate(__T("Send HeaderFile")).c_str(), Prefs->Translate(__T("Header file")).c_str());
 }
 
