@@ -78,7 +78,7 @@ TCustomButton*              Donate_Current;
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-const ZenLib::Char* MEDIAINFO_TITLE=__T("MediaArea.net/MediaInfo");
+extern const ZenLib::Char* MEDIAINFO_TITLE;
 const size_t Title_Pos=96; //TODO: Position of Title in General.csv, should shange this...
 MediaInfoList *I;
 //---------------------------------------------------------------------------
@@ -214,7 +214,12 @@ void __fastcall TMainF::GUI_Configure()
     else if (Prefs->Config(__T("Output"))==__T("XML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("MPEG-7")) {M_View_MPEG7Click(NULL); M_View_MPEG7->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_1.2")) {M_View_PBCoreClick(NULL); M_View_PBCore->Checked=true;}
-    else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.5")) {M_View_PBCoreClick(NULL); M_View_EBUCore_1_5->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("PBCore_2.0")) {M_View_PBCore2Click(NULL); M_View_PBCore2->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.5")) {M_View_EBUCore_1_5Click(NULL); M_View_EBUCore_1_5->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.6")) {M_View_EBUCore_1_6Click(NULL); M_View_EBUCore_1_6->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("FIMS_1.1")) {M_View_FIMS_1_1Click(NULL); M_View_FIMS_1_1->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("FIMS_1.2")) {M_View_FIMS_1_2Click(NULL); M_View_FIMS_1_2->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("FIMS_1.3")) {M_View_FIMS_1_3Click(NULL); M_View_FIMS_1_3->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("reVTMD")) {M_View_reVTMDClick(NULL); M_View_reVTMD->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("Custom")) {M_View_CustomClick(NULL); M_View_Custom->Checked=true;}
 
@@ -580,10 +585,10 @@ void __fastcall TMainF::Translate()
         }
         */
     }
-    if (Prefs->Donated)
+    //if (Prefs->Donated) //No more
     {
-        M_Digimetrics->Visible=false;
-        Tool_Digimetrics->Visible=false;
+        M_Tektronix->Visible=false;
+        Tool_Tektronix->Visible=false;
     }
 }
 
@@ -790,8 +795,18 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
             I->Option_Static(__T("Inform"), __T("MPEG-7"));
         else if (M_View_PBCore->Checked)
             I->Option_Static(__T("Inform"), __T("PBCore_1.2"));
+        else if (M_View_PBCore2->Checked)
+            I->Option_Static(__T("Inform"), __T("PBCore_2.0"));
         else if (M_View_EBUCore_1_5->Checked)
             I->Option_Static(__T("Inform"), __T("EBUCore_1.5"));
+        else if (M_View_EBUCore_1_6->Checked)
+            I->Option_Static(__T("Inform"), __T("EBUCore_1.6"));
+        else if (M_View_FIMS_1_1->Checked)
+            I->Option_Static(__T("Inform"), __T("FIMS_1.1"));
+        else if (M_View_FIMS_1_2->Checked)
+            I->Option_Static(__T("Inform"), __T("FIMS_1.2"));
+        else if (M_View_FIMS_1_3->Checked)
+            I->Option_Static(__T("Inform"), __T("FIMS_1.3"));
         else if (M_View_reVTMD->Checked)
             I->Option_Static(__T("Inform"), __T("reVTMD"));
         else
@@ -882,7 +897,7 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
     {
         Caption=MEDIAINFO_TITLE;
         if (Prefs->Donated)
-            Caption+=" - Sponsored by Digimetrics";
+            Caption+=" - Sponsored by Tektronix";
     }
     else if (FilesCount==1)
         //un fichier
@@ -1100,6 +1115,14 @@ void __fastcall TMainF::M_View_PBCoreClick(TObject *Sender)
     ChangePage(Page_Custom);
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_PBCore2Click(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(__T("PBCore_2.0"));
+    ToolBar_View_PBCore2->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_5Click(TObject *Sender)
 {
@@ -1108,6 +1131,38 @@ void __fastcall TMainF::M_View_EBUCore_1_5Click(TObject *Sender)
     ChangePage(Page_Custom);
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_EBUCore_1_6Click(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.6"));
+    ToolBar_View_EBUCore_1_6->Checked=true;
+    ChangePage(Page_Custom);
+}
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_FIMS_1_1Click(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(__T("FIMS_1.1"));
+    ToolBar_View_FIMS_1_1->Checked=true;
+    ChangePage(Page_Custom);
+}
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_FIMS_1_2Click(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(__T("FIMS_1.2"));
+    ToolBar_View_FIMS_1_2->Checked=true;
+    ChangePage(Page_Custom);
+}
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_FIMS_1_3Click(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(__T("FIMS_1.3"));
+    ToolBar_View_FIMS_1_3->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_CustomClick(TObject *Sender)
 {
@@ -1208,6 +1263,13 @@ void __fastcall TMainF::M_Debug_AdvancedClick(TObject *Sender)
     Refresh();
 }
 
+//---------------------------------------------------------------------------
+
+void __fastcall TMainF::M_Debug_FullParsingClick(TObject *Sender)
+{
+    M_Debug_FullParsing->Checked=!M_Debug_FullParsing->Checked;
+    I->Option_Static(__T("ParseSpeed"), M_Debug_FullParsing->Checked?__T("1"):__T("0"));
+}
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_Debug_DummyClick(TObject *Sender)
 {
@@ -1638,9 +1700,9 @@ void __fastcall TMainF::M_NewVersionClick(TObject *Sender)
     ShellExecute(NULL, NULL, (Ztring(__T("http://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("/MediaInfo/?NewVersionRequested=true")).c_str(), NULL, NULL, SW_SHOWNORMAL);
 }
 
-void __fastcall TMainF::M_DigimetricsClick(TObject *Sender)
+void __fastcall TMainF::M_TektronixClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://digi-metrics.com/"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("http://www.tek.com/file-based-qc-solutions"), NULL, NULL, SW_SHOWNORMAL);
 }
 //---------------------------------------------------------------------------
 
