@@ -182,15 +182,26 @@ __published:    // IDE-managed Components
     TMenuItem *M_View_XML;
     TMenuItem *M_View_MPEG7;
     TMenuItem *M_View_PBCore;
+    TMenuItem *M_View_PBCore2;
     TMenuItem *M_View_EBUCore_1_5;
-    TMenuItem *M_Digimetrics;
-    TToolButton *Tool_Digimetrics;
+    TMenuItem *M_View_EBUCore_1_6;
+    TMenuItem *M_View_FIMS_1_1;
+    TMenuItem *M_View_FIMS_1_2;
+    TMenuItem *M_View_FIMS_1_3;
+    TMenuItem *M_Tektronix;
+    TToolButton *Tool_Tektronix;
     TMenuItem *M_View_reVTMD;
     TMenuItem *ToolBar_View_XML;
     TMenuItem *ToolBar_View_MPEG7;
     TMenuItem *ToolBar_View_PBCore;
+    TMenuItem *ToolBar_View_PBCore2;
     TMenuItem *ToolBar_View_EBUCore_1_5;
+    TMenuItem *ToolBar_View_EBUCore_1_6;
+    TMenuItem *ToolBar_View_FIMS_1_1;
+    TMenuItem *ToolBar_View_FIMS_1_2;
+    TMenuItem *ToolBar_View_FIMS_1_3;
     TMenuItem *ToolBar_View_reVTMD;
+    TMenuItem *M_Debug_FullParsing;
     void __fastcall FormResize(TObject *Sender);
     void __fastcall M_Help_AboutClick(TObject *Sender);
     void __fastcall M_Options_PreferencesClick(TObject *Sender);
@@ -246,10 +257,16 @@ __published:    // IDE-managed Components
     void __fastcall M_NewVersionClick(TObject *Sender);
     void __fastcall M_View_MPEG7Click(TObject *Sender);
     void __fastcall M_View_PBCoreClick(TObject *Sender);
+    void __fastcall M_View_PBCore2Click(TObject *Sender);
     void __fastcall M_View_EBUCore_1_5Click(TObject *Sender);
+    void __fastcall M_View_EBUCore_1_6Click(TObject *Sender);
+    void __fastcall M_View_FIMS_1_1Click(TObject *Sender);
+    void __fastcall M_View_FIMS_1_2Click(TObject *Sender);
+    void __fastcall M_View_FIMS_1_3Click(TObject *Sender);
     void __fastcall M_View_XMLClick(TObject *Sender);
-    void __fastcall M_DigimetricsClick(TObject *Sender);
+    void __fastcall M_TektronixClick(TObject *Sender);
     void __fastcall M_View_reVTMDClick(TObject *Sender);
+    void __fastcall M_Debug_FullParsingClick(TObject *Sender);
 private:    // User declarations
 public:        // User declarations
     MESSAGE void __fastcall HandleDropFiles (TMessage&);
